@@ -728,7 +728,7 @@ class Thalassa:
 				# publish time
 				elif 'newer than:' == tag[:11]:
 					value = tag[11:]
-					if re.match('^[0-9]*$', value):
+					if re.match('^[0-9]*$', value) and 4 < len(value):
 						value = int(value)
 					else:
 						value = string_to_timestamp(value)
@@ -736,7 +736,7 @@ class Thalassa:
 						filters['newer than'] = value
 				elif 'older than:' == tag[:11]:
 					value = tag[11:]
-					if re.match('^[0-9]*$', value):
+					if re.match('^[0-9]*$', value) and 4 < len(value):
 						value = int(value)
 					else:
 						value = string_to_timestamp(value)
@@ -1465,18 +1465,25 @@ class Thalassa:
 						elif tag:
 							plain_tags.append(tag)
 
+					tag_col = 'tag'
+					tag_value = '?'
+					# case insensitivity
+					if True:
+						tag_col = 'LOWER(tag)'
+						tag_value = 'LOWER(?)'
+						tag = tag.lower()
 					for tag in plain_tags:
-						sql += ' AND file_id IN (SELECT file_id FROM tags WHERE tag == ?)'
+						sql += ' AND file_id IN (SELECT file_id FROM tags WHERE ' + tag_col + ' == ' + tag_value + ')'
 						values.append(tag)
 					for tag in negation_plain_tags:
-						sql += ' AND file_id NOT IN (SELECT file_id FROM tags WHERE tag == ?)'
+						sql += ' AND file_id NOT IN (SELECT file_id FROM tags WHERE ' + tag_col + ' == ' + tag_value + ')'
 						values.append(tag)
 					for tag in partial_tags:
-						sql += ' AND file_id IN (SELECT file_id FROM tags WHERE tag LIKE ? ESCAPE ?)'
+						sql += ' AND file_id IN (SELECT file_id FROM tags WHERE ' + tag_col + ' LIKE ' + tag_value + ')'
 						values.append(tag)
 						values.append('\\')
 					for tag in negation_partial_tags:
-						sql += ' AND file_id NOT IN (SELECT file_id FROM tags WHERE tag LIKE ? ESCAPE ?)'
+						sql += ' AND file_id NOT IN (SELECT file_id FROM tags WHERE ' + tag_col + ' LIKE ' + tag_value + ' ESCAPE ?)'
 						values.append(tag)
 						values.append('\\')
 
