@@ -7,9 +7,16 @@ if (!is_file('installed')) {
 # php interface to thalassa_cli.py
 
 $config = json_decode(file_get_contents('thalassa_site_config.json'), true);
+
+$request_scheme = $config['force_request_scheme'];
+if ('' == $request_scheme) {
+	$request_scheme = $_SERVER['REQUEST_SCHEME'];
+}
+$config['request_scheme'] = $request_scheme;
+
 $config['cookie_domain'] = $_SERVER['SERVER_NAME'];
 $config['cookie_secure'] = false;
-if ('https' == $_SERVER['REQUEST_SCHEME']) {
+if ('https' == $config['request_scheme']) {
 	$config['cookie_secure'] = true;
 }
 $config['cookie_lifespan'] = time() + 63072000;
@@ -85,7 +92,7 @@ define('EXPOSE_TAGS', (AUTHORIZED || CONFIG['expose_tags']));
 # root thalassa uri
 $thalassa_uri = CONFIG['thalassa_uri'];
 if ('' == $thalassa_uri) {
-	$thalassa_uri = $_SERVER['REQUEST_SCHEME'] . '://' . $_SERVER['SERVER_NAME'];
+	$thalassa_uri = CONFIG['request_scheme'] . '://' . $_SERVER['SERVER_NAME'];
 	if (!in_array($_SERVER['SERVER_PORT'], [80, 443])) {
 		$thalassa_uri .= ':' . $_SERVER['SERVER_PORT'];
 	}
